import 'dart:async';

import 'package:flutter/services.dart';

class CashfreePGSDK {

  static List<String> _required = [
      "stage",
      "appId",
      "orderId",
      "orderAmount",
      "orderCurrency",
      "customerEmail",
      "customerPhone",
      "tokenData"
    ];

  // Function to initiate the web checkout flow.
  static Future<Map<dynamic, dynamic>> doPayment(Map<String, dynamic> inputs) {
    Future<Map<dynamic, dynamic>> response;
    for (String element in _required) {
      if (!inputs.containsKey(element) || inputs[element].toString().isEmpty) {
        return _failureResponse(element + " not provided");
      }
    }
    MethodChannel channel = const MethodChannel('cashfree_pg');
    // ignore: unnecessary_null_comparison
    if (channel != null) {
      response = channel.invokeMethod('doPayment', inputs);
    } else {
      response = _failureResponse('Invalid channel');
    }
    return response;
  }

  // Function to initiate UPI Intent
  static Future<Map<dynamic, dynamic>> doUPIPayment(Map<String, dynamic> inputs) {
    Future<Map<dynamic, dynamic>> response;
    for (String element in _required) {
      if (!inputs.containsKey(element) || inputs[element].toString().isEmpty) {
        return _failureResponse(element + " not provided");
      }
    }

    MethodChannel channel = const MethodChannel('cashfree_pg');
    // ignore: unnecessary_null_comparison
    if(channel != null) {
      response = channel.invokeMapMethod("doUPIPayment", inputs);
    } else {
      response = _failureResponse("Invalid Channel");
    }
    return response;
  }

  static Future<List> getUPIApps() {
    Future<List> response;
    MethodChannel channel = const MethodChannel("cashfree_pg");
    // ignore: unnecessary_null_comparison
    if(channel != null) {
      response = channel.invokeListMethod("getUPIApps");
    } else {
      var completer = new Completer<List>();
      completer.complete(<dynamic>[]);
      response = completer.future;
    }
    return response;
  }

  // creates a failure response
  static Future<Map<dynamic, dynamic>> _failureResponse(String s) {
    var completer = new Completer<Map<dynamic, dynamic>>();
    Map<dynamic, dynamic> failureResponse = new Map<dynamic, dynamic>();
    failureResponse['txMsg'] = s;
    failureResponse['txStatus'] = 'FAILED';
    completer.complete(failureResponse);
    return completer.future;
  }
}
